.. role:: hidden
    :class: hidden-section

ax.benchmark
============

.. automodule:: ax.benchmark
.. currentmodule:: ax.benchmark

Benchmark
---------


Benchmark Method
~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_method
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problem
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_problem
    :members:
    :undoc-members:
    :show-inheritance:


Benchmark Result
~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.benchmark_result
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark
~~~~~~~~~

.. automodule:: ax.benchmark.benchmark
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods Modular BoTorch
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.modular_botorch
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Methods Sobol
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.methods.sobol
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Metrics Base
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.metrics.base
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Metrics Benchmark
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.metrics.benchmark
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Metrics Jenatton
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.metrics.jenatton
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Metrics Utils
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.metrics.utils
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Registry
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.registry
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems High Dimensional Embedding
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hd_embedding
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Surrogate
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.surrogate
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Mixed Integer Synthetic
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.synthetic.discretized.mixed_integer
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems Jenatton
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.synthetic.hss.jenatton
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems PyTorchCNN
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hpo.pytorch_cnn
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Problems PyTorchCNN TorchVision
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.problems.hpo.torchvision
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Runners Base
~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.runners.base
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Runners BoTorch Test
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.runners.botorch_test
    :members:
    :undoc-members:
    :show-inheritance:

Benchmark Runners Surrogate
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.benchmark.runners.surrogate
    :members:
    :undoc-members:
    :show-inheritance:
